@@ -33,18 +33,22 @@ def taskchecker():
 
 
     if CONTAINERSTATE == "running":
-        print("Jenkins container is running")
+        print(bcolors.OKGREEN + "Jenkins container is running"+ bcolors.ENDC)
     else:
-        print("Container might be named improperly or not running. Please rename it as jenkins")
-
+        print(bcolors.FAIL + "Container might be named improperly or not running. Please rename it as jenkins"+ bcolors.ENDC)
+        sys.exit(1)
+        time.sleep(0.5)
 
     if PORT == "8080":
-        print("Jenkins container is running on the correct port")
+        print(bcolors.OKGREEN + "Jenkins container is running on the correct port"+ bcolors.ENDC)
     else:
-        print("Jenkins container is not running on the correct port")
-
+        print(bcolors.FAIL + "Jenkins container is not running on the correct port"+ bcolors.ENDC)
+        sys.exit(1)
+        time.sleep(0.5)
 
     if "jenkins" in IMAGE:
-        print("Jenkins container is running with right image")
+        print(bcolors.OKGREEN + "Jenkins container is running with right image"+ bcolors.ENDC)
     else:
-        print("Jenkins container is not running with right image")
\ No newline at end of file
+        print(bcolors.FAIL + "Jenkins container is not running with right image"+ bcolors.ENDC)
+        sys.exit(1)
+        time.sleep(0.5)        
